Transmogrify 0.1 documentation &mdash; Transmogrify v0.1beta2 documentation
# Transmogrify 0.1 documentation #
<p>Contents:</p>
* Getting Started
	* The URL Generator

* Installation
	* Dependencies

* Django Template Tag
	* transmogrify
	* thumbnail
	* resize
	* letterbox
	* forcefit
	* crop
	* filter
	* border

* Web Server Integration
	* Lighttpd Integration
	* Django Development Server Integration

* Reference
	* Settings

# Indices and tables #
* Index
* Module Index
* Search Page
